# Stereo 3D
## Python package
Package for generating 3D data from stereo images.

## Examples
See [Samples](https://github.com/i3drobotics/Stereo3D/tree/master/pyStereo3D/SampleScripts) for example scripts of using this package.

